@@ -304,11 +304,12 @@ test_that("ddml_fpliv computes with an ensemble procedure w/o LIE, multi D", {
 
 test_that("ddml_fpliv computes with multiple ensemble procedures, multi D", {
   # Simulate small dataset
-  nobs <- 200
+  nobs <- 100
   X <- cbind(1, matrix(rnorm(nobs*39), nobs, 39))
   Z <- matrix(rnorm(nobs*10), nobs, 10)
   UV <- matrix(rnorm(2*nobs), nobs, 2) %*% chol(matrix(c(1, 0.7, 0.7, 1), 2, 2))
-  D <-  cbind(X %*% runif(40) + Z %*% c(1, runif(9)) + UV[, 1], rnorm(nobs))
+  D <-  cbind(X %*% runif(40) + Z %*% c(1, runif(9)) + UV[, 1],
+              X %*% runif(40) + Z %*% c(1, runif(9)) + rnorm(nobs))
   y <- rowSums(D) + X %*% runif(40) + UV[, 2]
   # Define arguments
   learners <- list(list(fun = ols),
@@ -319,7 +320,7 @@ test_that("ddml_fpliv computes with multiple ensemble procedures, multi D", {
                                ensemble_type = c("ols", "nnls",
                                                  "singlebest", "average"),
                                cv_folds = 3,
-                               sample_folds = 3,
+                               sample_folds = 5,
                                silent = T)
   # Check output with expectations
   expect_equal(length(ddml_fpliv_fit$coef), 8)
